package
Version:
v0.0.0-...-ad160b0
Opens a new window with list of versions in this module.
Published: May 31, 2021
License: MulanPSL-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func RegisterOpts(opts string, fopts func())
注册驱动事件
opts : 事件
optst :类型
fopts : 具体的方法
Source Files
¶
Click to show internal directories.
Click to hide internal directories.